==> activity-center-api-3.5.62-20230922.151051-30-sources.jar: cn/com/duiba/activity/center/api/dto/equitycard/EquityCardPayRecordDto.java <==
package cn.com.duiba.activity.center.api.dto.equitycard;

import java.io.Serializable;
import java.math.BigDecimal;
import java.util.Date;

/**
 * @author zhangdaqing
 * @Description
 * @date 2023/9/13 20:34
 */
public class EquityCardPayRecordDto implements Serializable {
    /**
     * 主键
     */
    private Long id;

    /**
     * 权益卡配置id
     */
    private Long configId;

    /**
     * 用户id
     */
    private String userId;

    /**
     * 第三方订单id
     */
    private String bizId;

    /**
     * 支付金额
     */
    private BigDecimal payMoney;

    /**
     * 生效时间
     */
    private Date startTime;

    /**
     * 过期时间
     */
    private Date expireTime;

    /**
     * 创建时间
     */
    private Date gmtCreate;

    /**
     * 更新时间
     */
    private Date gmtModified;


    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Long getConfigId() {
        return configId;
    }

    public void setConfigId(Long configId) {
        this.configId = configId;
    }

    public String getUserId() {
        return userId;
    }

    public void setUserId(String userId) {
        this.userId = userId;
    }

    public String getBizId() {
        return bizId;
    }

    public void setBizId(String bizId) {
        this.bizId = bizId;
    }

    public BigDecimal getPayMoney() {
        return payMoney;
    }

    public void setPayMoney(BigDecimal payMoney) {
        this.payMoney = payMoney;
    }

    public Date getStartTime() {
        return startTime;
    }

    public void setStartTime(Date startTime) {
        this.startTime = startTime;
    }

    public Date getExpireTime() {
        return expireTime;
    }

    public void setExpireTime(Date expireTime) {
        this.expireTime = expireTime;
    }

    public Date getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public Date getGmtModified() {
        return gmtModified;
    }

    public void setGmtModified(Date gmtModified) {
        this.gmtModified = gmtModified;
    }
}

==> activity-center-api-3.6.11-20250112.025959-16-sources.jar: cn/com/duiba/activity/center/api/dto/equitycard/EquityCardPayRecordDto.java <==
package cn.com.duiba.activity.center.api.dto.equitycard;

import java.io.Serializable;
import java.math.BigDecimal;
import java.util.Date;

/**
 * @author zhangdaqing
 * @Description
 * @date 2023/9/13 20:34
 */
public class EquityCardPayRecordDto implements Serializable {
    /**
     * 主键
     */
    private Long id;

    /**
     * 权益卡配置id
     */
    private Long configId;

    /**
     * 用户id
     */
    private String userId;

    /**
     * 第三方订单id
     */
    private String bizId;

    /**
     * 支付金额
     */
    private Integer payMoney;

    /**
     * 生效时间
     */
    private Date startTime;

    /**
     * 过期时间
     */
    private Date expireTime;


    /**
     * 0未支付，1已支付
     */
    private Integer status;


    /**
     * 创建时间
     */
    private Date gmtCreate;

    /**
     * 更新时间
     */
    private Date gmtModified;


    public Integer getStatus() {
        return status;
    }

    public void setStatus(Integer status) {
        this.status = status;
    }

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Long getConfigId() {
        return configId;
    }

    public void setConfigId(Long configId) {
        this.configId = configId;
    }

    public String getUserId() {
        return userId;
    }

    public void setUserId(String userId) {
        this.userId = userId;
    }

    public String getBizId() {
        return bizId;
    }

    public void setBizId(String bizId) {
        this.bizId = bizId;
    }


    public Integer getPayMoney() {
        return payMoney;
    }

    public void setPayMoney(Integer payMoney) {
        this.payMoney = payMoney;
    }

    public Date getStartTime() {
        return startTime;
    }

    public void setStartTime(Date startTime) {
        this.startTime = startTime;
    }

    public Date getExpireTime() {
        return expireTime;
    }

    public void setExpireTime(Date expireTime) {
        this.expireTime = expireTime;
    }

    public Date getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public Date getGmtModified() {
        return gmtModified;
    }

    public void setGmtModified(Date gmtModified) {
        this.gmtModified = gmtModified;
    }
}
